@@ -2,9 +2,10 @@ export * from './Invoice';
 export * from './InvoiceDiscount';
 export * from './InvoiceInsurancePlan';
 export * from './InvoiceInsurancePlanItem';
-export * from './InvoiceInsurer';
+export * from './InvoicesInvoiceInsurancePlan';
 export * from './InvoiceInsurerPayment';
 export * from './InvoiceItem';
+export * from './InvoiceItemFinalisedInsurance';
 export * from './InvoiceItemDiscount';
 export * from './InvoicePatientPayment';
 export * from './InvoicePayment';
