@@ -17,6 +17,7 @@ export class SyncSession extends Model {
   declare pullUntil?: number;
   declare errors?: string;
   declare debugInfo?: Record<string, object>;
+  declare parameters?: Record<string, object>;
 
   static initModel({ primaryKey, ...options }: InitOptions) {
     super.init(
@@ -33,6 +34,7 @@ export class SyncSession extends Model {
         pullUntil: { type: DataTypes.BIGINT },
         errors: { type: DataTypes.ARRAY(DataTypes.TEXT) },
         debugInfo: { type: DataTypes.JSON },
+        parameters: { type: DataTypes.JSONB, allowNull: false, defaultValue: {} },
       },
       {
         ...options,
@@ -46,11 +48,11 @@ export class SyncSession extends Model {
    * As this writes to the table, it may contend locks.
    * For debugging information, use addDebugInfo() instead.
    */
-  static async setParameters(id: string, params: object) {
+  static async setParameters(id: string, params: { [key: string]: any }) {
     await this.sequelize.query(
       `
       UPDATE "sync_sessions"
-      SET "debug_info" = (COALESCE("debug_info"::jsonb, '{}'::jsonb) || $data::jsonb)::json
+      SET "parameters" = (COALESCE("parameters", '{}'::jsonb) || $data::jsonb)
       WHERE "id" = $id
       `,
       { bind: { id, data: JSON.stringify(params) } },
@@ -63,7 +65,7 @@ export class SyncSession extends Model {
    * can't obtain the write. For business-logic parameters, use
    * setParameters() instead.
    */
-  static async addDebugInfo(id: string, info: object) {
+  static async addDebugInfo(id: string, info: { [key: string]: any }) {
     // the SKIP LOCKED means we don't lock the sync_sessions table's row
     // if it's already contended. but that also means that we might lose
     // some debug info in some cases. so let's debug log it as well.
