@@ -43,9 +43,9 @@ export class TaskDesignation extends Model {
     );
   }
 
-  static buildSyncLookupQueryDetails() {
+  static async buildSyncLookupQueryDetails() {
     return {
-      select: buildSyncLookupSelect(this, {
+      select: await buildSyncLookupSelect(this, {
         patientId: 'encounters.patient_id',
       }),
       joins: buildEncounterLinkedSyncFilterJoins([this.tableName, 'tasks', 'encounters']),
