@@ -6,6 +6,29 @@ import { createMigrationAuditLog } from '../../utils/audit';
 import { AUDIT_MIGRATION_CONTEXT_KEY } from '@tamanu/constants';
 import { checkIsMigrationContextAvailable } from '../../utils/audit/checkIsMigrationContextAvailable';
 
+/**
+ * Enhances PostgreSQL "pending trigger events" errors with helpful guidance.
+ * This error occurs when a migration mixes DDL and DML on the same table.
+ */
+function enhancePendingTriggerError(error, migrationName) {
+  if (error?.original?.message?.includes('pending trigger events')) {
+    const enhanced = new Error(
+      `${error.message}\n\n` +
+        `HINT: This error occurs when a migration has both schema changes (DDL) and data changes (DML) ` +
+        `on the same table. PostgreSQL's deferred triggers queue events during DML, then block DDL.\n\n` +
+        `To fix, split "${migrationName}" into separate migrations:\n` +
+        `  1. First migration: schema changes (addColumn, removeColumn, etc.)\n` +
+        `  2. Second migration: data changes (UPDATE, INSERT, etc.)\n` +
+        `  3. Third migration: remaining schema changes (if any)\n\n` +
+        `See packages/database/CLAUDE.md for details.`,
+    );
+    enhanced.original = error.original;
+    enhanced.stack = error.stack;
+    return enhanced;
+  }
+  return error;
+}
+
 // before this, we just cut our losses and accept irreversible migrations
 const LAST_REVERSIBLE_MIGRATION = '1685403132663-systemUser.js';
 
@@ -36,7 +59,11 @@ export function createMigrationInterface(log, sequelize) {
           wrapContext.migrationName,
         );
         if (!isMigrationContextAvailable) {
-          return updown(...args);
+          try {
+            return await updown(...args);
+          } catch (error) {
+            throw enhancePendingTriggerError(error, wrapContext.migrationName);
+          }
         }
 
         // Create migration context object
@@ -50,8 +77,9 @@ export function createMigrationInterface(log, sequelize) {
         await sequelize.setTransactionVar(AUDIT_MIGRATION_CONTEXT_KEY, JSON.stringify(migrationContext));
 
         try {
-          const result = await updown(...args);
-          return result;
+          return await updown(...args);
+        } catch (error) {
+          throw enhancePendingTriggerError(error, wrapContext.migrationName);
         } finally {
           await sequelize.setTransactionVar(AUDIT_MIGRATION_CONTEXT_KEY, null);
         }
