@@ -17,11 +17,11 @@ export const ADD_SENSITIVE_FACILITY_ID_IF_APPLICABLE = `
     END
   `;
 
-export function buildEncounterLinkedLookupSelect(
+export async function buildEncounterLinkedLookupSelect(
   model: typeof Model,
   extraSelects?: Record<string, string>,
 ) {
-  return buildSyncLookupSelect(model, {
+  return await buildSyncLookupSelect(model, {
     patientId: 'encounters.patient_id',
     facilityId: ADD_SENSITIVE_FACILITY_ID_IF_APPLICABLE,
     ...extraSelects,
@@ -40,9 +40,9 @@ export function buildEncounterLinkedLookupJoins(
   ]);
 }
 
-export function buildEncounterLinkedLookupFilter(model: typeof Model) {
+export async function buildEncounterLinkedLookupFilter(model: typeof Model) {
   return {
-    select: buildEncounterLinkedLookupSelect(model),
+    select: await buildEncounterLinkedLookupSelect(model),
     joins: buildEncounterLinkedLookupJoins(model),
   };
 }
