@@ -4,9 +4,10 @@ import { Command } from 'commander';
 import { log } from '@tamanu/shared/services/logging';
 import { performTimeZoneChecks } from '@tamanu/shared/utils/timeZoneCheck';
 import { selectFacilityIds } from '@tamanu/utils/selectFacilityIds';
+import { DEVICE_TYPES } from '@tamanu/constants';
 
 import { checkConfig } from '../checkConfig';
-import { initDeviceId } from '../sync/initDeviceId';
+import { initDeviceId } from '@tamanu/shared/utils';
 import { initTimesync } from '../services/initTimesync';
 import { performDatabaseIntegrityChecks } from '../database';
 import { CentralServerConnection, FacilitySyncManager } from '../sync';
@@ -32,7 +33,7 @@ export async function startTasks({ skipMigrationCheck, taskClasses, syncManager
     await context.sequelize.assertUpToDate({ skipMigrationCheck });
   }
 
-  await initDeviceId(context);
+  await initDeviceId({ context, deviceType: DEVICE_TYPES.FACILITY_SERVER });
   await checkConfig(context);
   await performDatabaseIntegrityChecks(context);
 
