@@ -1,4 +1,5 @@
 export * from './buildVersionCompatibilityCheck';
+export * from './getMetaServerHosts';
 export * from './getPatientAdditionalData';
 export * from './getPatientSurveyResponseAnswer';
 export * from './getResponseJsonSafely';
@@ -17,3 +18,6 @@ export * from './getLabTestsFromLabRequests';
 export * from './numeralTranslation';
 export * from './enumRegistry';
 export * from './invoice';
+export * from './medication';
+export * from './initDeviceId';
+export * from './errorHandlerProblem';
