@@ -13,15 +13,13 @@ const styles = StyleSheet.create({
 
   labelText: {
     fontSize: 8,
-    fontWeight: 400,
-    fontFamily: 'Helvetica-Bold',
+    fontWeight: 700,
     color: '#888888',
   },
 
   valueText: {
     fontSize: 8,
     fontWeight: 400,
-    fontFamily: 'Helvetica',
     color: '#888888',
   },
 });
@@ -33,10 +31,11 @@ export const useTextStyles = styles => {
 };
 
 export const MultiPageHeader = ({ documentName, documentSubname, patientName, patientId }) => {
+  const { getTranslation } = useLanguageContext();
   const valueStyles = useTextStyles(styles.valueText);
   const labelStyles = useTextStyles(styles.labelText);
 
-  const ValueText = props => <Text style={valueStyles} {...props} />;
+  const ValueText = props => <Text bold style={valueStyles} {...props} />;
   const LabelText = props => <Text style={labelStyles} {...props} />;
 
   const HeaderContent = () => (
@@ -49,10 +48,10 @@ export const MultiPageHeader = ({ documentName, documentSubname, patientName, pa
         </>
       )}
       <ValueText>|</ValueText>
-      <LabelText> Patient name</LabelText>
+      <LabelText> {getTranslation('general.patientName.label', 'Patient name')}</LabelText>
       <ValueText>: {patientName} </ValueText>
       <ValueText>|</ValueText>
-      <LabelText> Patient ID</LabelText>
+      <LabelText> {getTranslation('general.patientId.label', 'Patient ID')}</LabelText>
       <ValueText>: {patientId}</ValueText>
     </>
   );
